@@ -19,11 +19,11 @@
 		<div><?php $this->BcBaser->link($this->BcBaser->getImg('admin/icn_tool_down_on.png', array('title' => 'ダウンロード', 'alt' => 'ダウンロード')), $data['link'], array('target' => '_blank')) ?></div>
 	</td>
 	<td>
-		<?php echo $data['title'] ?>
+		<?php echo h($data['title']) ?>
 	</td>
 	<td><?php echo $data['version'] ?></td>
-	<td><?php echo $data['description'] ?></td>
-	<td><?php $this->BcBaser->link($data['author'], $data['authorLink'], array('target' => '_blank')) ?></td>
+	<td><?php echo h($data['description']) ?></td>
+	<td><?php $this->BcBaser->link($data['author'], $data['authorLink'], array('target' => '_blank', 'escape' => true)) ?></td>
 	<td style="width:10%;white-space: nowrap">
 		<?php echo $this->BcTime->format('Y-m-d', $data['created']) ?><br />
 		<?php echo $this->BcTime->format('Y-m-d', $data['modified']) ?>
